@@ -28,6 +28,8 @@
 #include <shlwapi.h>
 #include <fstream>
 
+using pws_os::CUUID;
+
 #ifdef _DEBUG
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -47,8 +49,10 @@ CString CAddEdit_Basic::CS_HIDE;
 IMPLEMENT_DYNAMIC(CAddEdit_Basic, CAddEdit_PropertyPage)
 
 CAddEdit_Basic::CAddEdit_Basic(CWnd *pParent, st_AE_master_data *pAEMD)
-  : CAddEdit_PropertyPage(pParent, CAddEdit_Basic::IDD, pAEMD),
-  m_pToolTipCtrl(NULL), m_bInitdone(false)
+  : CAddEdit_PropertyPage(pParent,
+                          CAddEdit_Basic::IDD, CAddEdit_Basic::IDD_SHORT,
+                          pAEMD),
+  m_pToolTipCtrl(NULL), m_bInitdone(false), m_thread(NULL)
 {
   if (CS_SHOW.IsEmpty()) { // one-time initializations
     HIDDEN_NOTES.LoadString(IDS_HIDDENNOTES);
@@ -201,8 +205,10 @@ BOOL CAddEdit_Basic::OnInitDialog()
   ApplyPasswordFont(GetDlgItem(IDC_PASSWORD));
   ApplyPasswordFont(GetDlgItem(IDC_PASSWORD2));
 
-  if (M_uicaller() != IDS_EDITENTRY || M_protected() == 0)
-    GetDlgItem(IDC_STATIC_PROTECTED)->ShowWindow(SW_HIDE);
+  if (M_uicaller() == IDS_EDITENTRY && M_protected() != 0) {
+    GetDlgItem(IDC_STATIC_PROTECTED)->ShowWindow(SW_SHOW);
+    m_stc_protected.SetColour(RGB(255,0,0));
+  }
 
   if (M_uicaller() != IDS_ADDENTRY) {
     m_pToolTipCtrl = new CToolTipCtrl;
@@ -234,7 +240,6 @@ BOOL CAddEdit_Basic::OnInitDialog()
       if (M_uicaller() == IDS_EDITENTRY && M_protected() != 0) {
         cs_ToolTip.LoadString(IDS_UNPROTECT);
         m_pToolTipCtrl->AddTool(GetDlgItem(IDC_STATIC_PROTECTED), cs_ToolTip);
-        m_stc_protected.SetColour(RGB(255,0,0));
       }
 
       m_pToolTipCtrl->Activate(TRUE);
@@ -253,12 +258,14 @@ BOOL CAddEdit_Basic::OnInitDialog()
   GetDlgItem(IDC_LAUNCH)->EnableWindow(M_URL().IsEmpty() ? FALSE : TRUE);
   GetDlgItem(IDC_SENDEMAIL)->EnableWindow(M_email().IsEmpty() ? FALSE : TRUE);
 
-  if (M_uicaller() == IDS_VIEWENTRY || (M_uicaller() == IDS_EDITENTRY && M_protected() != 0)) {
+  if (M_uicaller() == IDS_VIEWENTRY ||
+      (M_uicaller() == IDS_EDITENTRY && M_protected() != 0)) {
     // Change 'OK' to 'Close' and disable 'Cancel'
+    // "CancelToClose"  disables the System Command SC_CLOSE
+    // from clicking X on PropertySheet so have implemented
+    // CAddEdit_PropertySheet::OnSysCommand to deal with it
     CancelToClose();
-  }
 
-  if (M_uicaller() == IDS_VIEWENTRY) {
     // Disable Group Combo
     GetDlgItem(IDC_GROUP)->EnableWindow(FALSE);
 
@@ -475,42 +482,6 @@ LRESULT CAddEdit_Basic::OnQuerySiblings(WPARAM wParam, LPARAM )
       if (OnApply() == FALSE)
         return 1L;
       break;
-    case PP_PROTECT_CHANGED:
-    {
-      const BOOL bProtect = M_protected() != 0 ? TRUE : FALSE;
-      // Change 'OK' to 'Close' and disable 'Cancel'
-      if (bProtect == TRUE) {
-        CString cs_Close(MAKEINTRESOURCE(IDS_CLOSE));
-        m_ae_psh->GetDlgItem(IDOK)->SetWindowText(cs_Close);
-        m_ae_psh->GetDlgItem(IDCANCEL)->EnableWindow(TRUE);
-        m_ae_psh->GetDlgItem(ID_APPLY_NOW)->EnableWindow(FALSE);
-      } else {
-        // There isn't a "CloseToCancel()" function - do it ourselves!
-        if (m_ae_psh != NULL && IsWindow(m_ae_psh->m_hWnd)) {
-          CString cs_OK(MAKEINTRESOURCE(IDS_OK));
-          m_ae_psh->GetDlgItem(IDOK)->SetWindowText(cs_OK);
-          m_ae_psh->GetDlgItem(IDCANCEL)->EnableWindow(TRUE);
-          m_ae_psh->GetDlgItem(ID_APPLY_NOW)->EnableWindow(TRUE);
-        }
-      }
-
-      // Enable/Disable Group Combo
-      GetDlgItem(IDC_GROUP)->EnableWindow(1 - bProtect);
-
-      // Enable/Disable normal Edit controls
-      GetDlgItem(IDC_TITLE)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_USERNAME)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_PASSWORD)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_PASSWORD2)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_NOTES)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_NOTESWW)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_URL)->SendMessage(EM_SETREADONLY, bProtect, 0);
-      GetDlgItem(IDC_EMAIL)->SendMessage(EM_SETREADONLY, bProtect, 0);
-
-      // Enable/Disable Button
-      GetDlgItem(IDC_RANDOM)->EnableWindow(1 - bProtect);
-      break;
-    }
   }
   return 0L;
 }
@@ -556,7 +527,7 @@ BOOL CAddEdit_Basic::PreTranslateMessage(MSG* pMsg)
 BOOL CAddEdit_Basic::OnApply()
 {
   if (M_uicaller() == IDS_VIEWENTRY || M_protected() != 0)
-    return CAddEdit_PropertyPage::OnApply();
+    return FALSE; //CAddEdit_PropertyPage::OnApply();
 
   CWnd *pFocus(NULL);
   CGeneralMsgBox gmb;
@@ -640,11 +611,7 @@ BOOL CAddEdit_Basic::OnApply()
     // Edit entry
     if (listindex != M_pDbx()->End()) {
       const CItemData &listItem = M_pDbx()->GetEntryAt(listindex);
-      uuid_array_t list_uuid, elem_uuid;
-      listItem.GetUUID(list_uuid);
-      M_pci()->GetUUID(elem_uuid);
-      bool notSame = (memcmp(list_uuid, elem_uuid, sizeof(uuid_array_t)) != 0);
-      if (notSame) {
+      if (listItem.GetUUID() != M_pci()->GetUUID()) {
         CSecString temp;
         temp.Format(IDS_ENTRYEXISTS, M_group(), M_title(), M_username());
         gmb.AfxMessageBox(temp);
@@ -1011,11 +978,11 @@ void CAddEdit_Basic::OnLaunch()
                                                        M_realpassword(),
                                                        M_realnotes(),
                                                        vactionverboffsets);
-  int iaction = CItemData::URL;
+
   const bool bDoAutoType = (GetKeyState(VK_CONTROL) & 0x8000) != 0;
 
   M_pDbx()->LaunchBrowser(sx_url.c_str(), sx_autotype, vactionverboffsets, bDoAutoType);
-  M_pDbx()->UpdateLastClipboardAction(iaction);
+  M_pDbx()->UpdateLastClipboardAction(CItemData::URL);
 
   if (bDoAutoType) {
     // Reset button
@@ -1214,7 +1181,7 @@ void CAddEdit_Basic::OnViewDependents()
 bool CAddEdit_Basic::CheckNewPassword(const StringX &group, const StringX &title,
                                       const StringX &user, const StringX &password,
                                       const bool bIsEdit, const CItemData::EntryType InputType, 
-                                      uuid_array_t &base_uuid, int &ibasedata, bool &b_msg_issued)
+                                      pws_os::CUUID &base_uuid, int &ibasedata, bool &b_msg_issued)
 {
   // b_msg_issued - whether this routine issued a message
   b_msg_issued = false;
@@ -1229,7 +1196,7 @@ bool CAddEdit_Basic::CheckNewPassword(const StringX &group, const StringX &title
 
   // Copy data back before possibly returning
   ibasedata = pl.ibasedata;
-  memcpy(base_uuid, pl.base_uuid, sizeof(uuid_array_t));
+  base_uuid = pl.base_uuid;
   if (!brc)    
     return false;
 
