@@ -18,7 +18,6 @@
 
 #include "core/PWScore.h"
 #include "core/Report.h"
-#include "core/uuidgen.h"
 
 #include "resource.h"
 #include "resource2.h"
@@ -139,7 +138,9 @@ BOOL CCompareResultsDlg::OnInitDialog()
                  {CItemData::POLICY, IDS_PWPOLICY, POLICY},
                  {CItemData::RUNCMD, IDS_RUNCOMMAND, RUNCMD},
                  {CItemData::DCA, IDS_DCA, DCA},
+                 {CItemData::SHIFTDCA, IDS_SHIFTDCA, SHIFTDCA},
                  {CItemData::EMAIL, IDS_EMAIL, EMAIL},
+                 {CItemData::PROTECTED, IDS_PROTECTED, PROTECTED},
                  {CItemData::SYMBOLS, IDS_SYMBOLS, SYMBOLS},
   };
 
@@ -340,6 +341,8 @@ void CCompareResultsDlg::AddCompareEntries(const bool bAddIdentical)
         m_LCResults.SetItemText(iItem, icol++, st_data.bsDiffs.test(CItemData::DCA) ? L"X" : L"-");
       if (m_bsFields.test(CItemData::EMAIL))
         m_LCResults.SetItemText(iItem, icol++, st_data.bsDiffs.test(CItemData::EMAIL) ? L"X" : L"-");
+      if (m_bsFields.test(CItemData::PROTECTED))
+        m_LCResults.SetItemText(iItem, icol++, st_data.bsDiffs.test(CItemData::PROTECTED) ? L"X" : L"-");
       if (m_bsFields.test(CItemData::SYMBOLS))
         m_LCResults.SetItemText(iItem, icol++, st_data.bsDiffs.test(CItemData::SYMBOLS) ? L"X" : L"-");
 
@@ -424,8 +427,8 @@ bool CCompareResultsDlg::ProcessFunction(const int ifunction, st_CompareData *ps
   if (m_column == indatabase || indatabase == BOTH) {
     pst_info->pcore0 = m_pcore0;
     pst_info->pcore1 = m_pcore1;
-    memcpy(pst_info->uuid0, pst_data->uuid0, sizeof(pst_info->uuid0));
-    memcpy(pst_info->uuid1, pst_data->uuid1, sizeof(pst_info->uuid1));
+    pst_info->uuid0 = pst_data->uuid0;
+    pst_info->uuid1 = pst_data->uuid1;
     pst_info->clicked_column = m_column;
 
     LRESULT lres = ::SendMessage(AfxGetApp()->m_pMainWnd->GetSafeHwnd(),
@@ -438,7 +441,7 @@ bool CCompareResultsDlg::ProcessFunction(const int ifunction, st_CompareData *ps
       switch (ifunction) {
         case CCompareResultsDlg::COPY_TO_ORIGINALDB:
           // UUID of copied entry returned - now update data
-          memcpy(pst_data->uuid0, pst_info->uuid0, sizeof(pst_info->uuid0));
+          pst_data->uuid0 = pst_info->uuid0;
 
           pos = m_pcore1->Find(pst_info->uuid1);
           ASSERT(pos != m_pcore1->GetEntryEndIter());
@@ -452,7 +455,7 @@ bool CCompareResultsDlg::ProcessFunction(const int ifunction, st_CompareData *ps
           break;
         case CCompareResultsDlg::COPY_TO_COMPARISONDB:
           // UUID of copied entry returned - now update data
-          memcpy(pst_data->uuid1, pst_info->uuid1, sizeof(pst_info->uuid1));
+          pst_data->uuid1 = pst_info->uuid1;
 
           pos = m_pcore0->Find(pst_info->uuid0);
           ASSERT(pos != m_pcore0->GetEntryEndIter());
@@ -495,25 +498,25 @@ st_CompareData * CCompareResultsDlg::GetCompareData(const LONG_PTR dwItemData, C
   switch (iList) {
     case IDENTICAL:
       cd_iter = std::find_if(self->m_Identical.begin(), self->m_Identical.end(),
-        equal_id(id));
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != self->m_Identical.end())
         retval = &*cd_iter;
       break;
     case BOTH:
       cd_iter = std::find_if(self->m_Conflicts.begin(), self->m_Conflicts.end(),
-        equal_id(id));
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != self->m_Conflicts.end())
         retval = &*cd_iter;
       break;
     case CURRENT:
       cd_iter = std::find_if(self->m_OnlyInCurrent.begin(), self->m_OnlyInCurrent.end(),
-        equal_id(id));
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != self->m_OnlyInCurrent.end())
         retval = &*cd_iter;
       break;
     case COMPARE:
       cd_iter = std::find_if(self->m_OnlyInComp.begin(), self->m_OnlyInComp.end(),
-        equal_id(id));
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != self->m_OnlyInComp.end())
         retval = &*cd_iter;
       break;
@@ -646,19 +649,22 @@ bool CCompareResultsDlg::CopyLeftOrRight(const bool bCopyLeft)
   switch (indatabase) {
     case BOTH:
       m_numConflicts--;
-      cd_iter = std::find_if(m_Conflicts.begin(), m_Conflicts.end(), equal_id(id));
+      cd_iter = std::find_if(m_Conflicts.begin(), m_Conflicts.end(),
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != m_Conflicts.end())
         m_Conflicts.erase(cd_iter);
       break;
     case CURRENT:
       m_numOnlyInCurrent--;
-      cd_iter = std::find_if(m_OnlyInCurrent.begin(), m_OnlyInCurrent.end(), equal_id(id));
+      cd_iter = std::find_if(m_OnlyInCurrent.begin(), m_OnlyInCurrent.end(),
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != m_OnlyInCurrent.end())
         m_OnlyInCurrent.erase(cd_iter);
       break;
     case COMPARE:
       m_numOnlyInComp--;
-      cd_iter = std::find_if(m_OnlyInComp.begin(), m_OnlyInComp.end(), equal_id(id));
+      cd_iter = std::find_if(m_OnlyInComp.begin(), m_OnlyInComp.end(),
+                             std::bind2nd(std::equal_to<int>(), id));
       if (cd_iter != m_OnlyInComp.end())
         m_OnlyInComp.erase(cd_iter);
       break;
@@ -676,9 +682,9 @@ bool CCompareResultsDlg::CopyLeftOrRight(const bool bCopyLeft)
   return true;
 }
 
-void CCompareResultsDlg::OnItemDoubleClick(NMHDR* /* pNMHDR */, LRESULT *pResult)
+void CCompareResultsDlg::OnItemDoubleClick(NMHDR *, LRESULT *pLResult)
 {
-  *pResult = 0;
+  *pLResult = 0;
 
   m_row = m_LCResults.GetNextItem(-1, LVNI_SELECTED);
 
@@ -700,9 +706,9 @@ void CCompareResultsDlg::OnItemDoubleClick(NMHDR* /* pNMHDR */, LRESULT *pResult
   OnCompareViewEdit();
 }
 
-void CCompareResultsDlg::OnItemRightClick(NMHDR* /* pNMHDR */, LRESULT *pResult)
+void CCompareResultsDlg::OnItemRightClick(NMHDR *, LRESULT *pLResult)
 {
-  *pResult = 0;
+  *pLResult = 0;
 
   m_row = m_LCResults.GetNextItem(-1, LVNI_SELECTED);
 
@@ -774,9 +780,9 @@ void CCompareResultsDlg::OnItemRightClick(NMHDR* /* pNMHDR */, LRESULT *pResult)
   }
 }
 
-void CCompareResultsDlg::OnColumnClick(NMHDR* pNMHDR, LRESULT* pResult)
+void CCompareResultsDlg::OnColumnClick(NMHDR *pNotifyStruct, LRESULT *pLResult)
 {
-  NMHEADER *pNMHeaderCtrl  = (NMHEADER *)pNMHDR;
+  NMHEADER *pNMHeaderCtrl  = (NMHEADER *)pNotifyStruct;
 
   // Get column number to CItemData value
   int isortcolumn = pNMHeaderCtrl->iItem;
@@ -816,7 +822,7 @@ void CCompareResultsDlg::OnColumnClick(NMHDR* pNMHDR, LRESULT* pResult)
   hdi.fmt |= ((m_bSortAscending == TRUE) ? HDF_SORTUP : HDF_SORTDOWN);
   pHDRCtrl->SetItem(isortcolumn, &hdi);
 
-  *pResult = TRUE;
+  *pLResult = TRUE;
 }
 
 /*
@@ -898,7 +904,9 @@ void CCompareResultsDlg::WriteReportData()
     const CString csx_policy(MAKEINTRESOURCE(IDS_COMPPWPOLICY));
     const CString csx_runcmd(MAKEINTRESOURCE(IDS_COMPRUNCOMMAND));
     const CString csx_dca(MAKEINTRESOURCE(IDS_COMPDCA));
+    const CString csx_shiftdca(MAKEINTRESOURCE(IDS_COMPSHIFTDCA));
     const CString csx_email(MAKEINTRESOURCE(IDS_COMPEMAIL));
+    const CString csx_protected(MAKEINTRESOURCE(IDS_COMPPROTECTED));
     const CString csx_symbols(MAKEINTRESOURCE(IDS_COMPSYMBOLS));
 
     for (cd_iter = m_Conflicts.begin(); cd_iter != m_Conflicts.end();
@@ -918,7 +926,9 @@ void CCompareResultsDlg::WriteReportData()
       if (st_data.bsDiffs.test(CItemData::POLICY)) buffer += csx_policy;
       if (st_data.bsDiffs.test(CItemData::RUNCMD)) buffer += csx_runcmd;
       if (st_data.bsDiffs.test(CItemData::DCA)) buffer += csx_dca;
+      if (st_data.bsDiffs.test(CItemData::SHIFTDCA)) buffer += csx_shiftdca;
       if (st_data.bsDiffs.test(CItemData::EMAIL)) buffer += csx_email;
+      if (st_data.bsDiffs.test(CItemData::PROTECTED)) buffer += csx_protected;
       if (st_data.bsDiffs.test(CItemData::SYMBOLS)) buffer += csx_symbols;
 
       // Time fields
