@@ -20,7 +20,6 @@
 #define IDD_IMPORT_TEXT                 125
 #define IDD_IMPORT_XML                  126
 #define IDD_KEYCHANGE_DIALOG            127
-#define IDD_OPTIONS                     129
 #define IDD_PASSKEYENTRY                130
 #define IDD_PASSKEYENTRY_FIRST          131
 #define IDD_PASSKEYENTRY_WITHEXIT       132
@@ -37,7 +36,6 @@
 #define IDD_QUERYSETDEF                 144
 #define IDD_SECURECLEAR                 145
 #define IDD_TRYAGAIN                    146
-#define IDD_USERNAMEENTRY               147
 #define IDD_PWFONTDIALOG                148
 #define IDD_SAMPLETEXT                  149
 #define IDD_SETFILTERS                  150
@@ -72,6 +70,7 @@
 #define IDI_LOCKEDICON                  181
 #define IDI_MBASKICON                   182
 #define IDI_MBINFOICON                  183
+#define IDI_MBINFOICON                  183
 #define IDI_MBSTOPICON                  184
 #define IDI_MBWARNICON                  185
 #define IDI_ALIAS                       186
@@ -158,7 +157,6 @@
 #define IDB_COPYNOTES_CLASSIC           313
 #define IDB_COPYNOTES_NEW               314
 #define IDB_COPYNOTES_NEW_D             315
-#define IDB_COPYNOTES_NEW32             316
 #define IDB_COPYPASSWORD_CLASSIC        317
 #define IDB_COPYPASSWORD_NEW            318
 #define IDB_COPYPASSWORD_NEW_D          319
@@ -222,7 +220,6 @@
 #define IDB_RESTORE_CLASSIC             377
 #define IDB_RESTORE_NEW                 378
 #define IDB_RESTORE_NEW_D               379
-#define IDB_RESTORE_NEW32               380
 #define IDB_SAVE_CLASSIC                381
 #define IDB_SAVE_NEW                    382
 #define IDB_SAVE_NEW_D                  383
@@ -272,7 +269,6 @@
 #define IDB_UNCHECKED                   427
 #define IDB_EMPTY                       428
 #define IDB_BLANK                       429
-#define IDD_EXPORTFILTERS               430
 #define IDB_DRAGGROUP_NEW               431
 #define IDB_DRAGTITLE_NEW               432
 #define IDB_DRAGUSER_NEW                433
@@ -340,9 +336,21 @@
 #define IDD_WZADVANCEDBOTTOM            496
 #define IDD_WZSELECTDB                  497
 #define IDD_WZFINISH                    498
+#define IDB_DRAGAUTOX_CLASSIC           499
+#define IDB_DRAGAUTOX_NEW               500
+#define IDD_ADDEDIT_BASIC_SHORT         501
+#define IDD_ADDEDIT_DATETIMES_SHORT     502
+#define IDD_ADDEDIT_PASSWORDPOLICY_SHORT 503
+#define IDD_ADDEDIT_ADDITIONAL_SHORT    504
+#define IDD_PS_BACKUP_SHORT             505
+#define IDD_PS_DISPLAY_SHORT            506
+#define IDD_PS_MISC_SHORT               507
+#define IDD_PS_PASSWORDPOLICY_SHORT     508
+#define IDD_PS_SHORTCUTS_SHORT          509
+#define IDD_PS_SYSTEM_SHORT             510
+#define IDD_INPUTBOX                    511
 #define IDC_APPVERSION                  1000
 #define IDC_VERSION                     1001
-#define IDC_BROWSE                      1002
 #define IDC_CREATE_DB                   1003
 #define IDC_EXIT                        1004
 #define IDC_PASSWORD                    1005
@@ -367,7 +375,6 @@
 #define IDC_OPEN                        1024
 #define IDC_RANDOM                      1025
 #define IDC_LOCKONMINIMIZE              1026
-#define IDC_DEFPWSHOW                   1027
 #define IDC_DEFPWSHOWINEDIT             1028
 #define IDC_USEDEFUSER                  1029
 #define IDC_QUERYSETDEF                 1030
@@ -378,8 +385,6 @@
 #define IDC_DEFPWLENGTH                 1036
 #define IDC_MESSAGE                     1037
 #define IDC_QUERYCHECK                  1038
-#define IDC_STATIC_RULES                1039
-#define IDC_MAKEDEF                     1040
 #define IDC_NEW                         1041
 #define IDC_STATIC_LOGO                 1042
 #define IDC_ALWAYSONTOP                 1043
@@ -432,8 +437,8 @@
 #define IDC_STATIC_RESTART              1097
 #define IDC_STATIC_MAXREITEMS           1098
 #define IDC_MAXREITEMS                  1099
-#define IDC_URL                         1101
-#define IDC_AUTOTYPE                    1102
+#define IDC_URL                         1100
+#define IDC_AUTOTYPE                    1101
 #define IDC_EMAIL                       1102
 #define IDC_EXPIRYDATE                  1103
 #define IDC_EXPIRYTIME                  1104
@@ -450,32 +455,24 @@
 #define IDC_XTIME                       1115
 #define IDC_STATIC_RMTIME               1116
 #define IDC_RMTIME                      1117
-#define IDC_XTIME_CLEAR                 1118
-#define IDC_XTIME_SET                   1119
 #define IDC_MAINTAINDATETIMESTAMPS      1121
 #define IDC_STATIC_DTGROUP              1122
 #define IDC_STATIC_DTEXPGROUP           1123
-#define IDC_LEFT_HIDEABLE               1126
-#define IDC_RIGHT_HIDEABLE              1127
 #define IDC_EXPIRED_PASSWORD_LIST       1128
 #define IDC_RESPIN                      1132
 #define IDC_MRUSPIN                     1133
 #define IDC_PWHSPIN                     1134
-#define IDC_STATIC_PWHGROUP             1135
 #define IDC_PWHISTORY_LIST              1136
 #define IDC_SAVEPWHISTORY               1137
 #define IDC_MAXPWHISTORY                1138
 #define IDC_DEFPWHNUM                   1139
 #define IDC_COPY_OLDPW_TO_CLIPBOARD     1140
 #define IDC_CLEAR_PWHIST                1141
-#define IDC_STATIC_PWHIST               1142
 #define IDC_SAVE_PWHIST                 1143
 #define IDC_STATIC_OLDPW1               1144
-#define IDC_SHOW_PWHIST                 1145
-#define IDC_XML_IMPORT_RESULTS          1147
 #define IDC_PASSWORD2                   1149
 #define IDC_CLEAR_HISTORY               1150
-#define IDC_REPORT2CLIPBOARD            1150
+#define IDC_REPORT2CLIPBOARD            1151
 #define IDC_ADVANCED_LIST               1152
 #define IDC_ADVANCED_SELECTED           1153
 #define IDC_ADVANCED_SELECTSOME         1154
@@ -498,7 +495,6 @@
 #define IDC_SETMAXPWHISTORY             1186
 #define IDC_STATIC_UPDATEPWHISTORY      1187
 #define IDC_REGDEL                      1188
-#define IDC_SHOWNOTES                   1189
 #define IDC_DEFNOTESSHOWINEDIT          1190
 #define IDC_DATABASENAME                1191
 #define IDC_DATABASEFORMAT              1192
@@ -531,8 +527,9 @@
 #define IDC_DATABASECOMBO               1222
 #define IDC_BTN_BROWSE                  1223
 #define IDC_SPCL_TXT                    1225
-#define IDC_SELECTBYDATETIME            1228
-#define IDC_SELECTBYDAYS                1229
+#define IDC_SELECTBYDATETIME            1227
+#define IDC_SELECTBYDAYS                1228
+#define IDC_SELECTBYNONE                1229
 #define IDC_EXPDAYS                     1230
 #define IDC_EXPDAYSSPIN                 1231
 #define IDC_PREWARNEXPIRY               1232
@@ -542,7 +539,7 @@
 #define IDC_DEFENABLEGRIDLINES          1246
 #define IDC_LIST_HEADER                 1247
 #define IDC_CPLIST                      1248
-#define IDC_DEFAULTAUTOTYPE             1249
+#define IDC_DB_DEFAULTAUTOTYPE          1249
 #define IDC_MINIMIZEONAUTOTYPE          1250
 #define IDC_ALTBROWSER_CMDLINE          1251
 #define IDC_DEFUNSHOWINTREE             1254
@@ -562,14 +559,10 @@
 #define IDC_STATIC_ISANALIAS            1269
 #define IDC_NEWVER_STATUS               1272
 #define IDC_VISIT_WEBSITE               1273
-#define IDC_TRAYICONCOLOUR              1274
-#define IDC_TRAYICON                    1275
 #define IDC_RST_BLK                     1276
 #define IDC_RST_BLUE                    1277
 #define IDC_RST_WHITE                   1278
 #define IDC_RST_YELLOW                  1279
-#define IDC_SETPWPOLICY                 1281
-#define IDC_CLEARPWPOLICY               1282
 #define IDC_SAMPLETEXT                  1283
 #define IDC_TREATWHITESPACEASEMPTY      1284
 #define IDC_STATIC_LC1                  1285
@@ -633,7 +626,6 @@
 #define IDC_FILTEREXPORT                1346
 #define IDC_FILTERPROPERTIES            1347
 #define IDC_STATIC_FILTERNAME           1348
-#define IDC_STATIC_ACTIONS              1349
 #define IDC_STATIC_GROUP                1350
 #define IDC_STATIC_TITLE                1351
 #define IDC_STATIC_USERNAME             1352
@@ -649,8 +641,6 @@
 #define IDC_STATICSUBSETWARNING         1362
 #define IDC_DEFNOTESWRAP                1363
 #define IDC_STATIC_DTSTATS              1364
-#define IDC_TXT_FLDS_COMBO              1365
-#define IDC_TXT_FLD                     1366
 #define IDC_SHORTCUTLIST                1367
 #define IDC_RESETALLSHORTCUTS           1368
 #define IDC_SHORTCUTHOTKEY              1369
@@ -725,14 +715,31 @@
 #define IDC_USEOWNSYMBOLS               1439
 #define IDC_OWNSYMBOLS                  1440
 #define IDC_STATIC_DEFAULTSYMBOLS       1441
+#define IDC_DEFAULTAUTOTYPE             1442
+#define IDC_STATIC_DRAGAUTO             1443
+#define IDC_COPYPSWDURL                 1444
+#define IDC_STATIC_IDLEMINS             1445
+#define IDC_STATIC_NUMPWSDHIST          1446
+#define IDC_STATIC_DEFAUTOTYPE          1447
+#define IDC_STATIC_PSWDLENGTH           1448
+#define IDC_SHIFT_DOUBLE_CLICK_ACTION   1449
+#define IDC_SHIFT_DCA_DEFAULT           1450
+#define IDC_STATIC_PREFERENCES          1453
+#define IDC_STATIC_DB_PREFS_RO_WARNING  1454
+#define IDC_DATABASE_NAME               1455
+#define IDC_DATABASE_DESCRIPTION        1456
+#define IDC_CHANGE_DESCRIPTION          1457
+#define IDC_CHANGE_NAME                 1458
+#define IDC_INPUTBOX_TEXT               1459
+#define IDC_INPUTBOX_CHAR_COUNT         1460
 
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        499
+#define _APS_NEXT_RESOURCE_VALUE        512
 #define _APS_NEXT_COMMAND_VALUE         30001
-#define _APS_NEXT_CONTROL_VALUE         1442
+#define _APS_NEXT_CONTROL_VALUE         1461
 #define _APS_NEXT_SYMED_VALUE           166
 #endif
 #endif
